@@ -1,69 +1,88 @@
 /*
  * This file is part of LibKGAPI library
  *
- * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
+ * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
- * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "contactfetchjob.h"
-#include "account.h"
 #include "contact.h"
 #include "contactsservice.h"
-#include "debug.h"
+#include "../debug.h"
 #include "utils.h"
+#include "account.h"
+
+#include <QtNetwork/QNetworkRequest>
+#include <QtNetwork/QNetworkReply>
 
-#include <QNetworkReply>
-#include <QNetworkRequest>
-#include <QUrlQuery>
 
 using namespace KGAPI2;
 
 class Q_DECL_HIDDEN ContactFetchJob::Private
 {
-public:
+  public:
     Private(ContactFetchJob *parent);
 
     QNetworkRequest createRequest(const QUrl &url);
 
-    bool fetchDeleted = true;
+    bool fetchDeleted;
     QString contactId;
-    quint64 timestamp = 0;
+    quint64 timestamp;
     QString filter;
 
-private:
-    ContactFetchJob *const q;
+  private:
+    ContactFetchJob * const q;
 };
 
-ContactFetchJob::Private::Private(ContactFetchJob *parent)
-    : q(parent)
+ContactFetchJob::Private::Private(ContactFetchJob *parent):
+    fetchDeleted(true),
+    timestamp(0),
+    q(parent)
 {
 }
 
-QNetworkRequest ContactFetchJob::Private::createRequest(const QUrl &url)
+QNetworkRequest ContactFetchJob::Private::createRequest(const QUrl& url)
 {
-    QNetworkRequest request(url);
+    QNetworkRequest request;
+    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
     request.setRawHeader("GData-Version", ContactsService::APIVersion().toLatin1());
+    request.setUrl(url);
 
     QStringList headers;
     auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    for (const QByteArray &str : std::as_const(rawHeaderList)) {
+    Q_FOREACH(const QByteArray &str, rawHeaderList) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
+    qCDebug(KGAPIRaw) << headers;
 
     return request;
 }
 
-ContactFetchJob::ContactFetchJob(const AccountPtr &account, QObject *parent)
-    : FetchJob(account, parent)
-    , d(new Private(this))
+ContactFetchJob::ContactFetchJob(const AccountPtr& account, QObject* parent):
+    FetchJob(account, parent),
+    d(new Private(this))
 {
 }
 
-ContactFetchJob::ContactFetchJob(const QString &contactId, const AccountPtr &account, QObject *parent)
-    : FetchJob(account, parent)
-    , d(new Private(this))
+ContactFetchJob::ContactFetchJob(const QString& contactId, const AccountPtr& account, QObject* parent):
+    FetchJob(account, parent),
+    d(new Private(this))
 {
     d->contactId = contactId;
 }
@@ -123,14 +142,12 @@ void ContactFetchJob::start()
     QUrl url;
     if (d->contactId.isEmpty()) {
         url = ContactsService::fetchAllContactsUrl(account()->accountName(), d->fetchDeleted);
-        QUrlQuery query(url);
         if (d->timestamp > 0) {
-            query.addQueryItem(QStringLiteral("updated-min"), Utils::ts2Str(d->timestamp));
+            url.addQueryItem(QStringLiteral("updated-min"), Utils::ts2Str(d->timestamp));
         }
         if (!d->filter.isEmpty()) {
-            query.addQueryItem(QStringLiteral("q"), d->filter);
+            url.addQueryItem(QStringLiteral("q"), d->filter);
         }
-        url.setQuery(query);
     } else {
         url = ContactsService::fetchContactUrl(account()->accountName(), d->contactId);
     }
@@ -143,11 +160,12 @@ ObjectsList ContactFetchJob::handleReplyWithItems(const QNetworkReply *reply, co
 {
     FeedData feedData;
     ObjectsList items;
+    QString itemId;
     const QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     ContentType ct = Utils::stringToContentType(contentType);
     if (ct == KGAPI2::JSON) {
         if (d->contactId.isEmpty()) {
-            items = ContactsService::parseJSONFeed(rawData, feedData);
+            items =  ContactsService::parseJSONFeed(rawData, feedData);
         } else {
             items << ContactsService::JSONToContact(rawData);
         }
@@ -166,3 +184,6 @@ ObjectsList ContactFetchJob::handleReplyWithItems(const QNetworkReply *reply, co
 
     return ObjectsList();
 }
+
+
+
